@@ -2,12 +2,11 @@
   filterkmail_maildir.cpp  -  Kmail maildir mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "filterkmail_maildir.h"
 
 #include <KLocalizedString>
@@ -82,9 +81,9 @@ void FilterKMail_maildir::importMails(const QString &maildir)
     }
     setMailDir(maildir);
     /**
-    * If the user only select homedir no import needed because
-    * there should be no files and we surely import wrong files.
-    */
+     * If the user only select homedir no import needed because
+     * there should be no files and we surely import wrong files.
+     */
     if (mailDir() == QDir::homePath() || mailDir() == (QDir::homePath() + QLatin1Char('/'))) {
         filterInfo()->addErrorLogEntry(i18n("No files found for import."));
     } else {
@@ -151,11 +150,7 @@ void FilterKMail_maildir::importFiles(const QString &dirName)
                 _path = QStringLiteral("KMail-Import");
                 QString _tmp = dir.filePath(*mailFile);
                 _tmp.remove(mailDir(), Qt::CaseSensitive);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                const QStringList subFList = _tmp.split(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
                 const QStringList subFList = _tmp.split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
                 QStringList::ConstIterator end(subFList.end());
                 for (QStringList::ConstIterator it = subFList.constBegin(); it != end; ++it) {
                     QString _cat = *it;
